@@ -14,7 +14,7 @@ use overload (
 );
 
 use vars qw($VERSION);
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 =head1 NAME
 
@@ -634,8 +634,11 @@ sub _load_config {
     my $config = {};
 
     my @local;
+
+    my $pattern = File::Spec->catfile( $dir, '*' );
+    $pattern =~ s/\s/\\ /g;
     my $config_files = $self->{sort}
-        ->( $self, [ glob( File::Spec->catfile( $dir, '*' ) ) ] );
+        ->( $self, [ glob( $pattern ) ] );
 
     my $is_local = $self->{is_local};
     $self->debug( '', "Entering dir: $dir", '-' x ( length($dir) + 14 ) );
